import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';
import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { Dropdown } from './dropdown';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' },
  init: view => { view.tooltip(new Handler().call); }
});

const options = [
  { value: 'REGION', label: 'State' },
  { value: '%UNWEIGHTED ILI', label: 'ILI Percentage' },
  { value: 'ILITOTAL', label: 'ILI Total' },
  { value: 'NUM OF PROVIDERS', label: 'Providers' },
  { value: 'TOTAL PATIENTS', label: 'Total Patients' },
  { value: 'Others', label: 'Others' }
];
//const initialValue = 'ILITOTAL';
const initialValue = '%UNWEIGHTED ILI';
//const initialValue = 'NUM OF PROVIDERS';
const selectedValue = initialValue;

const App = () => {
  const [selectedValue, setSelectedValue] = useState(initialValue);
  console.log(selectedValue);
  console.log(window.selValue);
//Q: How to pass parameter fieldName into vl API call?
//export const viz01 = vl
const viz01 = vl
  .markCircle({ size: 100, opacity: 0.4 })
  .encode(
    vl.x().fieldQ('WEEK'),
//    vl.y().fieldQ(selectedValue).title(selectedValue),
    vl.color().fieldN('YEAR'),
    vl.size().fieldQ('ILITOTAL').title('ILI Total'),
    vl.tooltip().average('TOTAL PATIENTS')
  );

//Q: How to rerun the viz01 definition?
const run = async (fieldName) => {
  console.log(fieldName);
  const marks = viz01
    .data(await getData())
    .width(window.innerWidth)
    .height(window.innerHeight)
    .autosize({ type: 'fit', contains: 'padding' })
    .config(config);
  
  document.getElementById('root').appendChild(await marks.render());
};
//run(selectedValue);
  run(selectedValue);
  console.log(selectedValue);

  return (
   <div>
      <label for="dataF-select">Choose a data field:</label>
      <Dropdown
        options={options}
        id="dataF-select"
        selectedValue={selectedValue}
        onSelectedValueChange={setSelectedValue}
      />
    </div>
  );
};



const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
